# Copyright (C) 2010    Graham Binns <graham@grahambinns.com>
#
# This file is part of the Frabjous blog and site engine.
#
# Frabjous is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Frabjous is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public
# License along with Frabjous. If not, see
# <http://www.gnu.org/licenses/>.
"""Base classes for complex views."""

__metaclass__ = type
__all__ = [
    'BaseView',
    ]


class BaseView:
    """A Base View class from which all other View classes are derived."""

    def __init__(self, request, template):
        self.request = request
        self.response = None
        self.template = template

    def execute(self):
        """Process the request and return an appropriate HttpResponse."""
        raise NotImplementedError()

    @property
    def error_response(self):
        """Return the HttpResponse that should be returned on error."""
        raise NotImplementedError()

    @property
    def success_response(self): 
        """Return the HttpResponse that should be returned on success."""
        raise NotImplementedError()
